%global         pkgname Django

# Tests requiring Internet connections are disabled by default
# pass --with internet to run them (e.g. when doing a local rebuild
# for sanity checks before committing)
%bcond_with internet

Name:           python-django14
Version:        1.4.8
Release:        1%{?dist}.1
Summary:        A high-level Python Web framework

Group:          Development/Languages
License:        BSD
URL:            http://www.djangoproject.com/
Source0:        http://pypi.python.org/packages/source/D/%{pkgname}/%{pkgname}-%{version}.tar.gz
Source1:        simplejson-init.py

# patch tests to relax performance scalability requirements
Patch1:         Django-1.4-relax-scalability-req.patch
# skip tests requiring bundled eggs
Patch2:         Django-1.4-no-egg-test.patch

# patch tests to skip tests requiring internet connection
Patch3:         Django-1.4-no-internet-connection-tests.patch

# Use setuptools so that we can parallel install
Patch100: django1.4-parallel-version.patch

BuildArch:      noarch
# Note: No longer required in development version > 0.95
# BuildRequires:  python-setuptools
BuildRequires:  python2-devel
BuildRequires:  python-sphinx
BuildRequires:  python-setuptools
# for testing
BuildRequires:  python-simplejson

Requires:       python-simplejson

# allow users to use django with lowercase d
Provides:       %{pkgname} = %{version}-%{release}

# provide compatibility with python-django
Provides:       python-django = %{version}-%{release}
Provides:       Django = %{version}-%{release}
Obsoletes:      python-django < 1.4.5-3

%description
Django is a high-level Python Web framework that encourages rapid
development and a clean, pragmatic design. It focuses on automating as
much as possible and adhering to the DRY (Don't Repeat Yourself)
principle.

%package doc
Summary:        Documentation for Django
Group:          Documentation
Requires:       %{name} = %{version}-%{release}

Provides:       %{pkgname}-docs = %{version}-%{release}

%description doc
This package contains the documentation for the Django high-level
Python Web framework.

%prep
%setup -q -n %{pkgname}-%{version}

# remove bundled eggs
find . -name "*.egg" -exec rm -f '{}' \;

# patch tests to relax performance scalability requirements
%patch1 -p1 -b .relax-scalability-req

# patch tests to skip tests requiring bundled eggs
%patch2 -p1 -b .no-egg-test.patch

%if ! %{with internet}
# patch tests to skip tests requiring internet connection
#%patch3 -p1 -b .no-internet-connection-tests
%endif

%patch100 -p1

# empty files
for f in \
    django/contrib/humanize/models.py \
    django/contrib/markup/models.py \
    django/contrib/staticfiles/models.py \
    django/contrib/webdesign/models.py \
; do
  echo "# just a comment" > $f
done
echo "<!-- nothing -->" > django/contrib/flatpages/tests/templates/registration/login.html

# remove bundled simplejson (for tests)
cd django/utils/simplejson
rm -rf *
# and put the replacement stub in place
cp -p %{SOURCE1} __init__.py



%build
CFLAGS="$RPM_OPT_FLAGS" %{__python2} setup.py bdist_egg

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{python2_sitelib}
easy_install -m --prefix $RPM_BUILD_ROOT%{_usr} -Z dist/*.egg


%find_lang django
%find_lang djangojs
# append djangojs.lang to django.lang
cat djangojs.lang >> django.lang

# build documentation
(cd docs && mkdir djangohtml && mkdir -p _build/{doctrees,html} && make html)


# install man pages
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1/
cp -p docs/man/* $RPM_BUILD_ROOT%{_mandir}/man1/

# install bash completion script
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/
install -m 0644 -p extras/django_bash_completion \
   $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/

# Fix items in %%{_bindir}
mv $RPM_BUILD_ROOT%{_bindir}/django-admin.py $RPM_BUILD_ROOT%{_bindir}/django-admin

# remove .po files
find $RPM_BUILD_ROOT -name "*.po" | xargs rm -f

# Fix permissions
chmod +x \
  $RPM_BUILD_ROOT%{python_sitelib}/*.egg/django/contrib/admin/static/admin/js/compress.py \
  $RPM_BUILD_ROOT%{python_sitelib}/*.egg/django/bin/profiling/gather_profile_stats.py

# Renames to not conflict with the main python-django
mv $RPM_BUILD_ROOT/%{_bindir}/django-admin $RPM_BUILD_ROOT/%{_bindir}/django1.4-admin
mv $RPM_BUILD_ROOT%{_mandir}/man1/django-admin.1 $RPM_BUILD_ROOT%{_mandir}/man1/django1.4-admin.1

%check
export PYTHONPATH=$(pwd)
export LANG=en_US.utf8
cd tests
./runtests.py --settings=test_sqlite


%files -f django.lang 
%doc AUTHORS LICENSE README django/contrib/admin/static/admin/js/LICENSE-JQUERY.txt
%{_bindir}/django1.4-admin
%{_mandir}/man1/*
%dir %{_sysconfdir}/bash_completion.d/
%config(noreplace) %{_sysconfdir}/bash_completion.d/django_bash_completion

%{python_sitelib}/*.egg

%files doc
%defattr(-,root,root,-)
%doc docs/_build/html/*


%changelog
* Fri Feb 21 2014 Toshio Kuratomi <toshio@fedoraproject.org> - 1.4.8-1.1
- Initial test of parallel installable version

* Mon Sep 16 2013 Matthias Runge <mrunge@redhat.com> - 1.4.8-1
- update to 1.4.8, fix CVE-2013-1443 (DoS via large passwords)
- fixes rhbz#1008282

* Wed Sep 11 2013 Matthias Runge <mrunge@redhat.com> - 1.4.7-1
- update to 1.4.7, fix CVE 2013-4315

* Wed Aug 14 2013 Matthias Runge <mrunge@redhat.com> - 1.4.6-1
- security related update 

* Mon Aug 05 2013 Matthias Runge <mrunge@redhat.com> - 1.4.5-9
- fix docs build issue (rhbz#992884)

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.5-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Apr 29 2013 Matthias Runge <mrunge@redhat.com> - 1.4.5-7
- fix dates in changelog

* Mon Apr 29 2013 Matthias Runge <mrunge@redhat.com> - 1.4.5-6
- add obsoletes, conflicts

* Fri Apr 05 2013 Matthias Runge <mrunge@redhat.com> - 1.4.5-5
- provide python-django, Django

* Wed Apr 03 2013 Matthias Runge <mrunge@redhat.com> - 1.4.5-4
- removed references to ancient Fedora releases
- included JQUERY-LICENSE.txt
- removed bundled eggs and skipped tests requiring bundled eggs

* Thu Feb 28 2013 Matthias Runge <mrunge@redhat.com> - 1.4.5-3
- packaging for python-django14

* Thu Feb 21 2013 Matthias Runge <mrunge@redhat.com> - 1.4.5-2
- update to latest stable upstream version
- fix minor packaging issues introduced upstream

* Wed Feb 20 2013 Matthias Runge <mrunge@redhat.com> - 1.4.4-1
- update to 1.4.4 (rhbz #913024)
- Data leakage via admin history log CVE-2013-0305 (rhbz #913041)
- Formset denial-of-service CVE-2013-0306 (rhbz #913042)

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jan 24 2013 Matthias Runge <mrunge@redhat.com> - 1.4.3-2
- also obsolete version 1.4.3-1

* Sun Jan 13 2013 Matthias Runge <mrunge@redhat.com> - 1.4.3-2
- own directories (rhbz#894533)

* Tue Dec 11 2012 Matthias Runge <mrunge@redhat.com> - 1.4.3-1
- security update to upstream version 1.4.3
  https://www.djangoproject.com/weblog/2012/dec/10/security/

* Fri Nov 16 2012 Bohuslav Kabrda <bkabrda@redhat.com> - 1.4.2-2
- Bump obsoletes version, since there is still Django-1.4.2-1 out there.
- Fix a provide that should allow users to use "django" instead of "Django".

* Thu Oct 18 2012 Matthias Runge <mrunge@redhat.com> - 1.4.2-1
- security update to upstream version 1.4.2-1
  https://www.djangoproject.com/weblog/2012/oct/17/security/

* Thu Sep 20 2012 Matthias Runge <mrunge@redhat.com> - 1.4.1-2
- fix provides: Django

* Wed Aug 01 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.4.1-1
- update to 1.4.1 fixing CVE-2012-3442, CVE-2012-3443, and CVE-2012-3444

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed May 30 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.4-4
- fix for FTBFS using python 2.7.3 (thanks to  M.Cepl)

* Wed Mar 28 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.4-3
- revert change from 1.4-2
- really fix simplejson-import

* Tue Mar 27 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.4-2
- fix simplejson-import (port from django-1.3-package)

* Sun Mar 25 2012 Michel Salim <salimma@fedoraproject.org> - 1.4-1
- Update to 1.4

* Mon Mar 19 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.3.1-9
- spec cleanup

* Sat Mar 17 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.3.1-8
- patch tests to work on koji (no internet connection)

* Sat Mar 10 2012 Michel Salim <salimma@fedoraproject.org> - 1.3.1-7
- Enable tests
- Now obsoletes (last Django release+1)
- Mark Bash completion script as a configuration file

* Fri Mar 09 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.3.1-6
- add additional provides django = %%{version}-%%{release}

* Wed Mar 07 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.3.1-5
- rename package to python-django

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Oct 12 2011 Michel Salim <salimma@fedoraproject.org> - 1.3.1-3
- Package bash completion script

* Sat Sep 10 2011 Michel Salim <salimma@fedoraproject.org> - 1.3.1-2
- Switch to the 'html' doc builder, for easier navigation without a web server

* Sat Sep 10 2011 Michel Salim <salimma@fedoraproject.org> - 1.3.1-1
- Update to 1.3.1
- Remove workaround for non-functional -doc generation
- Deduplicate file listing

* Wed Mar 30 2011 Steve Milner <me@stevemilner.org> - 1.3-2
- Fix for BZ#693865

* Wed Mar 30 2011 Steve Milner <me@stevemilner.org> - 1.3-1
- Fix for es_MX upstream bug
- Update for upstream release

* Wed Feb  9 2011 Steve Milner <me@stevemilner.org> - 1.2.5-1
- Fix for CVE-2011-0697

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Jan  3 2011 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.2.4-1
- Update for multiple security issues (see http://www.djangoproject.com/weblog/2010/dec/22/security/)

* Sat Oct  9 2010 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.2.3-3
- Now build docs for F12+
- Added Django-remove-djangodocs-ext.patch

* Sat Oct  9 2010 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.2.3-2
- Moved to dirhtml for documentation generation

* Mon Sep 13 2010 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.2.3-1
- Update for http://www.djangoproject.com/weblog/2010/sep/10/123/

* Thu Sep  9 2010 Steve 'Ashcrow' Milner <me@stevemilner.org> - 1.2.2-1
- Update for CVE-2010-3082 (see http://www.djangoproject.com/weblog/2010/sep/08/security-release/)
- Removed Django-hash-compat-13310.patch as it is already included in this release

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 1.2.1-6
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Tue Jun  8 2010 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.2.1-5
- Added http://code.djangoproject.com/changeset/13310?format=diff&new=13310 per BZ#601212

* Thu Jun  3 2010 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.2.1-4
- Include egg in >= rhel6

* Thu Jun  3 2010 Michel Salim <salimma@fedoraproject.org> - 1.2.1-3
- Use generated %%{name}.lang instead of including each locale file by hand
- Temporarily make main package provide -doc on Rawhide, to fix upgrade path
  until upstream documentation builds with Sphinx 1.0

* Thu May 27 2010 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.2.1-2
- Allow for building docs in F13 as it's only F14 freaking out

* Tue May 25 2010 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.2.1-1
- Update for new release.
- Added lang files per BZ#584866.
- Changed perms on %%{python_sitelib}/django/contrib/admin/media/js/compress.py
- Lots of explicit files listed in %%files in order to reduce duplicate file listings
- Docs are not built on F-13 for now

* Wed Oct 21 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1.1-2
- Removed po files per BZ#529188.

* Fri Oct  9 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1.1-1
- Update to fix http://www.djangoproject.com/weblog/2009/oct/09/security/
- Django-ignore-pyo-bz-495046.patch no longer needed.

* Wed Aug 26 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1-4
- EL-4 shouldn't get the sphinx docs.

* Wed Aug 26 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1-3
- ghosting admin py* is now FC9 and under.

* Thu Aug  6 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1-2
- Applied Daniel Mach's patch from bz#516016.

* Sat Aug  1 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.1-1
- Update for Django 1.1 release.
- Moved /usr/bin/django-admin.py to /usr/bin/django-admin
- sed macro is now being used
- Patch for bz#495046 applied.

* Wed Jul 29 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.3-6
- Attempted combined spec for F12/11/10 and EL5

* Wed Jul 29 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.3-4
- Older builds must ghost django-admin.py[c,o]

* Wed Jul 29 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.3-3
- Bump for tag issue.

* Wed Jul 29 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.3-2
- Fix changelog.

* Wed Jul 29 2009 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.3-1
- Upgrade for http://www.djangoproject.com/weblog/2009/jul/28/security/

* Thu Mar 12 2009 Michel Salim <salimma@fedoraproject.org> - 1.0.2-3
- Build HTML documentation (bug #484070)
- No longer excluding *.py? in bindir, F11's Python does not optimizes these

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Dec 14 2008 Michel Salim <salimma@fedoraproject.org> - 1.0.2-1
- Update to 1.0.2

* Sat Nov  1 2008 Steve 'Ashcrow' Milner <stevem@gnulinux.net> - 1.0.1-0.1.beta1
- Update to 1.0.1_beta_1

* Sat Sep  6 2008 Michel Salim <salimma@fedoraproject.org> - 1.0-1
- Update to final 1.0 release

* Tue Sep  2 2008 Michel Salim <salimma@fedoraproject.org> - 1.0-0.1.rc1%{?dist}
- CSRF security update: bz#460966

* Wed Aug 27 2008 Michel Salim <salimma@fedoraproject.org> - 1.0-0.1.beta2
- Update to 1.0 beta2

* Sat Aug 23 2008 Michel Salim <salimma@fedoraproject.org> - 1.0-0.1.beta1
- Update to 1.0 beta1

* Mon May 19 2008 Michel Salim <salimma@fedoraproject.org> - 0.96.2-1
- XSS security update: CVE-2008-2302 (bz# 442757-60)

* Sat Apr  5 2008 Michel Salim <salimma@fedoraproject.org> - 0.96.1-2
- Package .egg-info file on Fedora >= 9

* Thu Nov  1 2007 Michel Salim <michel.sylvan@gmail.com> 0.96.1-1
- i18n security update: CVE-2007-5712, bz#357051

* Sat Mar 24 2007 Michel Salim <michel.salim@gmail.com> - 0.96-1
- New upstream version

* Sun Jan 21 2007 Michel Salim <michel.salim@gmail.com> - 0.95.1-1
- Upstream security updates:
  http://www.djangoproject.com/weblog/2007/jan/21/0951/

* Sun Nov 12 2006 Michel Salim <michel.salim@gmail.com> - 0.95-1
- Initial package
